@@ -56,15 +56,7 @@ templates_files = [
             "request": "launch",
             "program": "${workspaceFolder}/src/main.py",
             "args": [],
-            "console": "integratedTerminal",
-            "justMyCode": true
-        },
-        {
-            "name": "Python: {{app}} module main File",
-            "type": "python",
-            "request": "launch",
-            "program": "${workspaceFolder}/src/{{app}}/{{ app }}.py",
-            "args": [],
+            "env": {},
             "console": "integratedTerminal",
             "justMyCode": true
         },
@@ -75,6 +67,7 @@ templates_files = [
             "cwd": "${workspaceFolder}",
             "module": "src.{{app}}.{{app}}",
             "args": [],
+            "env": {},
             "console": "integratedTerminal",
             "justMyCode": true
         },
@@ -83,6 +76,7 @@ templates_files = [
             "type": "python",
             "request": "launch",
             "program": "${file}",
+            "env": {},
             "console": "integratedTerminal",
             "justMyCode": true
         }
@@ -134,6 +128,8 @@ classifiers = [
     "License :: OSI Approved :: {{ license }} License",
     "Operating System :: OS Independent",
 ]
+dependencies = [
+]
 
 [project.urls]
 "Homepage" = "https://github.com/user/{{app}}"
@@ -237,6 +233,8 @@ else
     source ${BASE_DIR}/.venv/bin/activate
 fi
 
+python -m build 2>/dev/null >/dev/null || python -m pip install --upgrade pip build
+
 echo "Build"
 python -m build
 
@@ -291,6 +289,8 @@ else
     source ${BASE_DIR}/.venv/bin/activate
 fi
 
+python -m build 2>/dev/null >/dev/null || python -m pip install --upgrade pip build
+
 echo "Build"
 python -m build
 
@@ -319,6 +319,8 @@ PACKAGE={{app}}
 
 cd ${BASE_DIR}
 
+python -m build 2>/dev/null >/dev/null || python -m pip install --upgrade pip build
+
 echo Reinstall module
 python -m pip install --upgrade --force-reinstall dist/${PACKAGE}*whl
 
